#
# spec file for package xfce4-cpufreq-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.16.0
%define plugin cpufreq
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        1.2.9
Release:        1.1
Summary:        CPU Frequency Scaling Monitor Plugin for the Xfce Panel
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-cpufreq-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/1.2/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext >= 0.19.8
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gthread-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.17.2
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfce4-panel >= %{panel_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The CpuFreq scaling monitor plugin can be used to monitor the current CPU
frequency and currently active governor.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
# gcc10 workaround
export CFLAGS="%{optflags} -fcommon"
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libcpufreq.la

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_libdir}/xfce4/panel/plugins/libcpufreq.so*
%{_datadir}/icons/hicolor/*/apps/xfce4-cpufreq-plugin.*
%{_datadir}/xfce4/panel/plugins/cpufreq.desktop

%files lang -f %{name}.lang

%changelog
* Fri Dec 29 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.2.9
  * Update copyright year
  * build: Bump dependency versions and fix deprecation warnings
  * I18n: Update po/LINGUAS list
  * I18n: Update po/LINGUAS list
  * scan-build: Fix false positive file
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * scan-build: Add false positive file
  * build: clang: Fix -Wfortify-source
  * scan-build: Fix unix.Malloc
  * I18n: Update po/LINGUAS list
  * build: Get rid of intltool
  * Fix previous commit
  * Update copyright year
  * Remove deprecated project files
  * build: Add GLib requirement
  * Translation Updates
* Fri Dec 23 2022 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 1.2.8
  * Bump build requirements for Xfce 4.18.0
  * Remove code obsoleted by libxfce4util-4.17.2
  * Fix GLib warnings occurring with newer xfce4-dev-tools
  * Fix intltool lock file bug in make distcheck
  * Translation Updates
- Remove _service file
* Wed Feb  2 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.2.7
  * Use locale-independent floats in configuration files
  * Fix translations not showing in the GUI
  * Translation Updates
* Tue Feb  1 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.2.6
  * Prevent cur_freq sysfs reads from stalling plugin initialization
  * Enable fractional update internals
  * Prevent sysfs read latency from interfering with GUI updates
  * Improve static type-safety of signal handlers
  * Replace C pointers with reference-counted pointers
  * Cleanup configuration files
  * Bump libxfce4panel requirement from 4.12 to 4.14
  * Update copyright year
  * Bump required xdt-autogen version to 4.14.0
  * Update configure.ac.in syntax
  * Update and sort the list of authors
  * Manually update %%d to %%zu in translations
  * Translation Updates
* Fri Mar  5 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.2.5
  - Adjust CPU icon color according to frequency
  - Use 99th percentile as the max frequency when adjusting icon color
  - Display text using a drawing area instead of using a label with CSS
  - Enable font color reset
  - Disable font settings when not displaying text
  - Switch to symbolic close icons
  - Bump required version of Xfce UI to 4.14
  - Compute max_freq and min_freq when calculating avg/min/max
  - Delete font name from RC file if using the default font
  - Code cleanups, fixes and minor optimizations
  - Translation Updates
* Wed Feb  3 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.2.4
  * Display governors even if they differ among CPU cores
  * Enable fixed units in the frequency text box
  * Create the label widget if it does not exist
  * Update copyright year
  * Translation Updates
* Tue Jan 12 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.2.3
  * configure.ac: use AC_PROG_CC_C99
  * Remove duplicate information from configuration window's title
  * Fix missing-prototypes
  * Remove GSourceFunc casts
  * Fix font color memory leak
  * Fix fatal compiler warnings
  * Record release date in the NEWS file like in all previous releases
  * Fix CSS provider memory leak and an invalid line ordering in an
  * if-statement
  * Use heap allocations instead of stack allocations
  * Better handling of changes in the number of installed CPUs
  * Display the actual governor instead of "current"
  * Fix font size (gxo#panel-plugins/xfce4-cpufreq-plugin#5)
  * Translation Updates
* Tue Oct 27 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.2.2:
  * Update URLs and copyright year
  * Add basic GitLab pipeline
  * Fix compilation with gcc-10
  * Update URLs from goodies.x.o to docs.x.o (bxo#16156)
  * s/http/https
  * Fix build with panel 4.15
  * Replace GtkStock buttons
  * Rename applet to plugin (bxo#15582)
  * Post release tag bump
  * Translation Updates
* Mon Jun  8 2020 Maurizio Galli <maurizio.galli@gmail.com>
- add -fcommon to CFLAGS as temporary work around for gcc10 default
  changes
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
* Mon Oct 15 2018 Stefan Seyfried <seife+obs@b1-systems.com>
- update to 1.2.1:
  * Improved spacing in dialogs (bxo#14661)
  * Check if each cpu is online (bxo#14641)
  * Use xfce_panel_plugin_lookup_rc_file (bxo#11823)
  * Translation updates
* Fri May 25 2018 seife+obs@b1-systems.com
- update to 1.2.0:
  * Prefer sysfs to Intel pstate in cpufreq_linux_init (bxo#13835)
  * Add option to configure text color (bxo#13565)
  * Translation updates
- packaging: mark COPYING file as %%license
* Tue Nov 28 2017 seife+obs@b1-systems.com
- update to version 1.1.90
  - port to GTK-3
  - translation updates
- do not package ChangeLog, NEWS is enough
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to version 1.1.3
  - translation updates
* Tue Jun 23 2015 gber@opensuse.org
- update to version 1.1.2
  - fix IT_PROG_INTLTOOL warning
  - translation updates
* Tue Dec 23 2014 gber@opensuse.org
- update to version 1.1.1
  - fix panel resizing caused by freq format function (bxo#10385)
  - various other widget layout fixes and simplifications
  - fix missing return type of cpufreq_show_about (bxo#10343)
  - fix typo in panel-plugin/Makefile.am (bxo#10332)
  - various other fixes to the build system
  - many translation updates
- remove obsolete
  xfce4-panel-plugin-cpufreq-fix-missing-return-type.patch
* Sun Sep  8 2013 gber@opensuse.org
- update to version 1.1.0
  - support the Intel performance state driver
  - improve config dialog and use mnemonics
  - add a proper "About" dialog
  - add min, avg and max frequencies in cpu selection
  - add support for selecting a custom font
  - support showing icon only
  - improve overview window size and layout
  - remove code for showing the frame
  - rewrite layout code using >=xfce4-panel-4.9 features
  - remove code for deprecated APIs and <xfce4-panel-4.9
  - build plugin as a module
  - fix showing frequency of wrong CPU core
  - fix reading min frequency from cpufreq sysfs
  - support panel 4.9 features (deskbar mode)
  - port plugin to libxfce4ui
  - code clean up and refactoring
  - updates and fixes for build system files
- drop obsolete
  xfce4-panel-plugin-cpufreq-correctly-refresh-core.patch
- add xfce4-panel-plugin-cpufreq-fix-missing-return-type.patch in
  order to fix a missing return type (bxo#10343)
* Fri Apr 20 2012 gber@opensuse.org
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Tue Apr  3 2012 gber@opensuse.org
- added xfce4-panel-plugin-cpufreq-correctly-refresh-core.patch in
  order to correctly refresh the selected core rather than always
  the last one (bxo#7179)
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
